@@ -20,9 +20,9 @@ func ListAutoscalingGroups(s *session.Session) ([]Resource, error) {
 		func(page *autoscaling.DescribeAutoScalingGroupsOutput, lastPage bool) bool {
 			for _, asg := range page.AutoScalingGroups {
 				resources = append(resources, &AutoScalingGroup{
-					name: asg.AutoScalingGroupName,
-					svc:  svc,
-					tags: asg.Tags,
+					group: asg,
+					svc:   svc,
+					tags:  asg.Tags,
 				})
 			}
 			return !lastPage
@@ -36,14 +36,14 @@ func ListAutoscalingGroups(s *session.Session) ([]Resource, error) {
 }
 
 type AutoScalingGroup struct {
-	svc  *autoscaling.AutoScaling
-	name *string
-	tags []*autoscaling.TagDescription
+	svc   *autoscaling.AutoScaling
+	group *autoscaling.Group
+	tags  []*autoscaling.TagDescription
 }
 
 func (asg *AutoScalingGroup) Remove() error {
 	params := &autoscaling.DeleteAutoScalingGroupInput{
-		AutoScalingGroupName: asg.name,
+		AutoScalingGroupName: asg.group.AutoScalingGroupName,
 		ForceDelete:          aws.Bool(true),
 	}
 
@@ -56,7 +56,7 @@ func (asg *AutoScalingGroup) Remove() error {
 }
 
 func (asg *AutoScalingGroup) String() string {
-	return *asg.name
+	return *asg.group.AutoScalingGroupName
 }
 
 func (asg *AutoScalingGroup) Properties() types.Properties {
@@ -65,7 +65,8 @@ func (asg *AutoScalingGroup) Properties() types.Properties {
 		properties.SetTag(tag.Key, tag.Value)
 	}
 
-	properties.Set("Name", asg.name)
+	properties.Set("CreatedTime", asg.group.CreatedTime)
+	properties.Set("Name", asg.group.AutoScalingGroupName)
 
 	return properties
 }
